@@ -899,6 +899,7 @@ magnifier_transform_cursor (Magnifier *magnifier)
 		int size_x, size_y;
 		GdkPixbuf *scaled_cursor_pixbuf;
 		GdkPixbuf *scaled_mask_pixbuf;
+		GdkPixbuf *scaled_mask_pixbuf_alpha;
 		GdkPixbuf *cursor_pixbuf;
 		GdkPixbuf *mask_pixbuf;
 		GdkPixmap *cursor_pixmap = magnifier->priv->cursor;
@@ -970,12 +971,13 @@ magnifier_transform_cursor (Magnifier *magnifier)
 		}
 		else
 		    DBG (g_warning ("cursor pixmap is non-drawable."));
-		scaled_mask_pixbuf = gdk_pixbuf_add_alpha (
+		scaled_mask_pixbuf_alpha = gdk_pixbuf_add_alpha (
 			scaled_mask_pixbuf, True, 0, 0, 0);
-		gdk_pixbuf_render_threshold_alpha (scaled_mask_pixbuf,
+		gdk_pixbuf_render_threshold_alpha (scaled_mask_pixbuf_alpha,
 						   magnifier->priv->cursor_mask,
 						   0, 0, 0, 0, size_x, size_y,
 						   0x80);
+		g_object_unref (scaled_mask_pixbuf_alpha);
 		g_object_unref (scaled_cursor_pixbuf);
 		g_object_unref (scaled_mask_pixbuf);
 		g_object_unref (mgc);
@@ -1397,6 +1399,7 @@ magnifier_set_property (BonoboPropertyBag *bag,
 		break;
 	default:
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
+		break;
 	};
 }
 
